import React, { Component } from 'react';
import { Popover, Card, List, Form, Table, Button, Input, InputNumber, Select, Dropdown, Menu, Icon } from 'antd';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';

import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import FooterToolbar from '../../../components/FooterToolbar';
import TerminalSelectModal from './terminal';
import MerchantProductSelectModal from './product';
import { productType, pageSize } from '../../../utils/config';
import styles from './index.less';

@Form.create()
@connect(state => ({
  terminal: state.terminal,
  orderItem: state.orderDetail,
  mproduct: state.mproduct,
}))
export default class CreateOrder extends Component {
  // 终端选择弹框相关的回调方法
  handleTerminalSelectBtnClick = () => {
    this.props.dispatch({ type: 'orderDetail/showTerminalModal' });
    this.props.dispatch({
      type: 'terminal/query',
      payload: {
        pageNo: 1,
        pageSize,
      },
    });
  }

  handleTerminalModalOk = (record) => {
    this.props.dispatch({
      type: 'orderDetail/savePickedTerminal',
      payload: {
        userCode: record.code,
        userName: record.name,
        campusName: record.campusName,
        merchantName: record.merchantName,
        merchantId: record.merchantId,
      },
    });
  }

  handleTerminalModalCancel = () => {
    this.props.dispatch({ type: 'orderDetail/hideTerminalModal' });
  }

  handleTerminalModalSearch = () => {

  }

  handleTerminalModalTableChange = () => {

  }

  // 产品选择弹框相关的回调方法
  handleProductSelectBtnClick = () => {
    const { orderItem } = this.props;
    const { currentItem } = orderItem;
    const { merchantId } = currentItem;
    this.props.dispatch({ type: 'orderDetail/showProductModal' });
    this.props.dispatch({
      type: 'mproduct/query',
      payload: {
        pageNo: 1,
        pageSize,
        merchantId,
      },
    });
  }

  handleProductModalSearch = () => {

  }

  handleProductModalTableChange = () => {

  }

  handleProductModalOk = (data) => {
    this.props.dispatch({
      type: 'orderDetail/savePickedProducts',
      payload: data,
    });
  }

  handleProductModalCancel = () => {
    this.props.dispatch({ type: 'orderDetail/hideProductModal' });
  }

  render() {
    const { orderItem, terminal, mproduct, form } = this.props;
    const { terminalModalShow, productModalShow } = orderItem;
    const currentItem = {
      userCode: '15790324883489',
      userName: '教室六',
      campusName: '北京-北京市 西城区-科贸A座',
      merchantName: '贝尔安亲',
      merchantId: '555',
      products: [{
        id: 'p1',
        code: 'P-01',
        name: '语文一年级上册',
        type: 'COURSE',
        coverUrl: 'https://os.alipayobjects.com/rmsportal/QBnOOoLaAfKPirc.png',
        goods: [{
          id: '1',
          chargeUnit: '年',
          cpPrice: 2000,
          merchantPrice: 3000,
          terminalPrice: 4000,
        }, {
          id: '2',
          chargeUnit: '半年',
          cpPrice: 1000,
          merchantPrice: 2000,
          terminalPrice: 3000,
        }, {
          id: '3',
          chargeUnit: '季',
          cpPrice: 500,
          merchantPrice: 800,
          terminalPrice: 1000,
        }],
      }, {
        id: 'package-1',
        code: '课程包-01',
        name: '小学一年级语文课程包',
        type: 'PACKAGE',
        coverUrl: 'https://os.alipayobjects.com/rmsportal/QBnOOoLaAfKPirc.png',
        goods: [{

        }],
      }],
    };
    const { userCode, userName, campusName, merchantName, merchantId, products } = currentItem;

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 2 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 12 },
        md: { span: 22 },
      },
    };

    const columns = [{
      title: '产品信息',
      dataIndex: 'coverUrl',
      key: 0,
      render: (text, record) => (
        <Popover
          content={
            <Card hoverable style={{ width: 350, height: 550 }} cover={<img alt="" src={text} />}>
              <Card.Meta
                title={`${record.name}/${record.code}`}
                description={`类型: ${productType[record.type]}`}
              />
            </Card>
          }
        >
          <img src={text} width={50} />
        </Popover>
      ),
    }, {
      title: '价格类型',
      dataIndex: 'goods',
      key: 1,
      render: (text, record) => (
        <Dropdown
          overlay={
            <Menu>
              {record.goods.map(item => <Menu.Item key={item.id}>{`${item.terminalPrice}¥/${item.chargeUnit}`}</Menu.Item>)}
            </Menu>
          }
        ><a>付费方式<Icon type="down" /></a>
        </Dropdown>
      ),
    }, {
      title: '优惠价格',
      dataIndex: 'adjustPrice',
      key: 2,
      render: (text, record) => (
        <InputNumber
          min={0}
          defaultValue={0}
          formatter={value => `¥ ${value}`.replace(/\B(?=(\d{3})+(?!\d))/g, ',')}
          parser={value => value.replace(/\¥\s?|(,*)/g, '')}
        />
      ),
    }, {
      title: '实际售价',
      dataIndex: 'finalPrice',
      key: 3,
    }, {
      title: '数量',
      dataIndex: 'quantity',
      key: 4,
      render: (text, record) => (
        <InputNumber
          min={1}
          defaultValue={1}
          formatter={value => `x ${value}`.replace(/\B(?=(\d{3})+(?!\d))/g, ',')}
          parser={value => value.replace(/\x\s?|(,*)/g, '')}
        />
      ),
    }, {
      title: '单位',
      dataIndex: 'chargeUnit',
      key: 5,
    }];

    return (
      <PageHeaderLayout>
        <Card>
          <Form>
            <Form.Item label="选择终端" {...formItemLayout}>
              <Button onClick={this.handleTerminalSelectBtnClick} type="primary" size="small" icon="plus-circle-o">选择</Button>
              {userCode ? (
                <List
                  size="small"
                  bordered
                  style={{ width: '50%' }}
                  dataSource={[`终端编号: ${userCode}`, `终端名称: ${userName}`, `所属校区: ${campusName}`, `所属渠道: ${merchantName}`]}
                  renderItem={item => <List.Item>{item}</List.Item>}
                />
) : null}
            </Form.Item>
            <Form.Item label="收货地址" {...formItemLayout}>
              <Input.TextArea style={{ width: '50%' }} placeholder="请填写或使用默认地址" />
            </Form.Item>
            <Form.Item label="添加备注" {...formItemLayout}>
              <Input.TextArea style={{ width: '50%' }} placeholder="请输入(选填)" />
            </Form.Item>
            <Form.Item label="添加商品" {...formItemLayout}>
              <Button onClick={this.handleProductSelectBtnClick} disabled={!merchantId} type="primary" size="small" icon="plus-circle-o">添加</Button>
              <Table
                size="large"
                className={styles.table}
                rowKey={record => record.id}
                pagination={false}
                columns={columns}
                dataSource={products}
              />
            </Form.Item>
          </Form>
          {/* 终端选择弹框 */}
          <TerminalSelectModal
            rowKeyName="id"
            modalVisible={terminalModalShow}
            style={{ top: 20 }}
            width={660}
            onOk={this.handleTerminalModalOk}
            onCancel={this.handleTerminalModalCancel}
            onSearch={this.handleTerminalModalSearch}
            fsTableDataSource={terminal.list || []}
            fsTableLoading={terminal.listLoading}
            fsTablePagination={terminal.pagination}
            fsTableOnChange={this.handleTerminalModalTableChange}
          />
          {/* 渠道产品选择弹框 */}
          <MerchantProductSelectModal
            rowKeyName="id"
            modalVisible={productModalShow}
            selTableData={products || []}
            style={{ top: 20 }}
            width={660}
            fsTableDataSource={mproduct.list}
            fsTableLoading={mproduct.listLoading}
            fsTablePagination={mproduct.pagination}
            onOk={this.handleProductModalOk}
            onCancel={this.handleProductModalCancel}
            onSearch={this.handleProductModalSearch}
            fsTableOnChange={this.handleProductModalTableChange}
          />
        </Card>
        <FooterToolbar>
          <Dropdown.Button
            overlay={
              <Menu>
                <Menu.Item>￥1000 / 年</Menu.Item>
                <Menu.Item>￥2000 / 季</Menu.Item>
              </Menu>
            }
          />
          <Button>取消</Button>
          <Button type="primary">完成</Button>
        </FooterToolbar>
      </PageHeaderLayout>
    );
  }
}
